@@ -12,8 +12,9 @@ module.exports = Vue.extend({
         self.isEditing = params && params.mode === 'edit';
 
         for (var id in attrs) {
-            if (attrs.hasOwnProperty(id)) {
+            if (attrs.hasOwnProperty(id) && attrs[id].skipAutoRender !== true) {
                 target.setAttribute(id, attrs[id].value);
+
                 switch (id) {
                 case 'innerHTML':
                     target.innerHTML = attrs[id].value;
