@@ -41,10 +41,10 @@ function Localize () {
 
         // Try to autodetect locale
         if (autodetect) {
-            var spoofLocale = getLocaleFromQueryString();
-            var navigatorLocale = navigator.language;
+            var spoof = getLocaleFromQueryString();
+            var navLocale = navigator.language;
             var defaultLang = self.defaultLang;
-            self.locale = spoofLocale || locale || navigatorLocale || defaultLang;
+            self.locale = spoof || locale || navLocale || defaultLang;
             model.locale = self.locale;
         }
 
