@@ -11,7 +11,6 @@ var i18n = require('./i18n');
 var locale = require('../locale');
 var router = require('./router');
 var model = require('./model')();
-var restorePath = require('./restore-path');
 
 // Register views
 Vue.component('loader', require('../views/loader'));
@@ -24,9 +23,9 @@ Vue.component('sign-in', require('../views/sign-in'));
 Vue.component('discover', require('../views/discover'));
 Vue.component('templates', require('../views/templates'));
 Vue.component('profile', require('../views/profile'));
-Vue.component('sign-up', require('../views/sign-up'));
 
 Vue.component('play', require('../views/play'));
+Vue.component('data', require('../views/data'));
 Vue.component('edit', require('../views/edit'));
 Vue.component('add', require('../views/add'));
 Vue.component('block', require('../views/block'));
@@ -46,8 +45,7 @@ var app = new Vue({
         params: null
     },
     created: function () {
-        model.restore(function onLogin(err) {
-            if (err) console.error(err);
+        model.restore(function () {
 
             // i18n
             i18n.setLocale(model.data.locale, true);
@@ -55,17 +53,6 @@ var app = new Vue({
             // Route
             router(app);
 
-            restorePath({
-                history: model.data.history && model.data.history.path,
-                offline: model.data.offline
-            });
-
-        }, function onLogout(err) {
-            // i18n
-            i18n.setLocale(null, true);
-
-            // Router
-            router(app);
         });
     }
 });
