@@ -9,6 +9,7 @@ var MakeDrive = require('makedrive');
 var watch = require('watchjs').watch;
 var config = require('../config');
 var page = require('page');
+var restorePath = require('./restore-path');
 
 /**
  * Constructor
@@ -24,7 +25,7 @@ function Model (options) {
     self.options = options || {};
 
     if (!self.options.noConnect) {
-       self.auth = require('./auth');
+        self.auth = require('./auth');
     }
 
     // Internal
@@ -60,21 +61,22 @@ function Model (options) {
         self._logger(err);
     });
 
-    self._sync.on('completed', function() {
+    self._sync.on('completed', function () {
         self._logger('Sync Completed');
         self._dirty = false;
     });
-    self._sync.on('syncing', function() {
+    self._sync.on('syncing', function () {
         self._logger('Syncing');
     });
-
 }
 
 // Utility function to determine if makedrive
 // is currently connected
 Model.prototype.isConnected = function () {
     var self = this;
-    return [self._sync.SYNC_CONNECTED, self._sync.SYNC_CONNECTING].indexOf(self._sync.state) > -1;
+    var isConnected = self._sync.SYNC_CONNECTED;
+    var isConnecting = self._sync.SYNC_CONNECTING;
+    return [isConnected, isConnecting].indexOf(self._sync.state) > -1;
 };
 
 // Utility function to clear local filesystem
@@ -108,7 +110,7 @@ Model.prototype.readFileAsJson = function (filename, options, callback) {
             // Try parsing it.
             try {
                 file = JSON.parse(file);
-            } catch(e) {
+            } catch (e) {
                 file = options.defaultData;
             }
             // Call the callback!
@@ -124,7 +126,7 @@ Model.prototype.readFileAsJson = function (filename, options, callback) {
     });
 };
 
-Model.prototype.restore = function (callback, onLogout) {
+Model.prototype.restore = function (callback) {
     var self = this;
 
     // Set offline callback
@@ -136,39 +138,47 @@ Model.prototype.restore = function (callback, onLogout) {
         }
         self.data.offline = true;
         callback();
+        restorePath({
+            history: self.data.history && self.data.history.path,
+            offline: self.data.offline
+        });
     };
 
     // First, read local filesystem.
-    self.readFileAsJson(self._ns, {defaultData: self.data}, function (file) {
+    self.readFileAsJson(self._ns, {
+        defaultData: self.data
+    }, function (file) {
         // Restore to model.data
-    if (typeof file.history !== 'undefined') self.data.history = file.history;
-        if (typeof file.apps !== 'undefined') self.data.apps = file.apps;
-        if (typeof file.locale !== 'undefined') self.data.locale = file.locale;
-        if (typeof file.offline !== 'undefined') self.data.offline = file.offline;
+        if (typeof file.history !== 'undefined') {
+            self.data.history = file.history;
+        }
+        if (typeof file.apps !== 'undefined') {
+            self.data.apps = file.apps;
+        }
+        if (typeof file.locale !== 'undefined') {
+            self.data.locale = file.locale;
+        }
+        if (typeof file.offline !== 'undefined') {
+            self.data.offline = file.offline;
+        }
+
         self._logger('Data restored');
         self.observe();
         self._ready = true;
 
         // Were we in offline mode? If so, restore it.
         // Just read locally if no connect
-        if (self.data.offline || self.options.noConnect || global.location.search.match('offline=true') || config.OFFLINE) {
+        if (self.data.offline ||
+        self.options.noConnect ||
+        global.location.search.match('offline=true') ||
+        config.OFFLINE) {
             self.offlineConnect();
         }
         if (self.options.noConnect) {
             return;
         }
 
-        // Otherwise, let's set up a connection
-        var syncTimeout;
-
-        self._sync.on('connected', function() {
-            global.clearTimeout(syncTimeout);
-            self._logger('Makedrive connected');
-            callback();
-        });
-
-        self.auth.on('login', function (user) {
-            self._logger('login');
+        function onLogin(user) {
             self.data.user = user;
 
             if (!self.isConnected()) {
@@ -181,25 +191,65 @@ Model.prototype.restore = function (callback, onLogout) {
                 }, 10000);
                 self._logger('Connecting...');
             }
-        });
 
-        self.auth.on('logout', function () {
+            restorePath({
+                history: self.data.history && self.data.history.path,
+                offline: self.data.offline
+            });
+        }
+
+        function onLogout() {
             self._logger('logout');
             self.data.user = {};
             if (self.data.offline) return;
 
-            // Redirect
-            onLogout();
             // Todo: clear local FS
             if (self.isConnected()) {
                 self._sync.disconnect();
             }
+            callback();
             page('/sign-in');
+        }
+
+        // Otherwise, let's set up a connection
+        var syncTimeout;
+
+        self._sync.on('connected', function () {
+            global.clearTimeout(syncTimeout);
+            self._logger('Makedrive connected');
+            callback();
         });
 
-        if (!self.data.offline) {
-            self.auth.verify();
-        }
+        self.auth = require('./auth')();
+
+        var setup = false;
+
+        self.auth.on('error', function (err) {
+            if (err.cors === 'rejected') {
+                global.clearTimeout(syncTimeout);
+                self.offlineConnect();
+            }
+        });
+
+        self.auth.on('verified', function (user) {
+            self._logger('verified');
+            if (setup) {
+                return;
+            } else if (user) {
+                onLogin(user);
+            } else {
+                onLogout();
+                setup = true;
+            }
+        });
+        self.auth.on('login', function (user) {
+            self._logger('login');
+            onLogin(user);
+        });
+        self.auth.on('logout', function () {
+            self._logger('logout');
+            onLogout();
+        });
 
     });
 };
@@ -213,7 +263,7 @@ Model.prototype.restore = function (callback, onLogout) {
  */
 Model.prototype.save = function (callback) {
     var self = this;
-    callback = callback || function (){};
+    callback = callback || function () {};
 
     var putItem = JSON.stringify(self.data);
     self._fs.writeFile(self._ns, putItem, function (item) {
@@ -241,7 +291,6 @@ Model.prototype.observe = function () {
 };
 
 var model;
-
 function instantiateModel (options) {
     // If the instance doesn't exist, create it.
     if (!model) model = new Model(options);
