@@ -9,7 +9,7 @@ module.exports = function (options) {
 
     var defaultPath = '/templates';
     var coldStart = ['/', '/index.html'];
-    var noRestore = offline ? coldStart : coldStart.concat(['/sign-in', '/sign-up']);
+    var noRestore = offline ? coldStart : coldStart.concat(['/sign-in']);
 
     function isAllowed(path) {
         return noRestore.indexOf(path) === -1;
@@ -19,11 +19,20 @@ module.exports = function (options) {
     if (isAllowed(pathname)) return;
 
     // Restore from history... but not if history is in noRestore
+    var message;
     if (history && isAllowed(history)) {
-        console.log('[Loader] You visited ' + pathname + '; redirecting to your history, ' + history);
+        message = '[Loader] You visited ' +
+            pathname +
+            '; redirecting to your history, ' +
+            history;
+        console.log(message);
         page(history);
     } else {
-        console.log('[Loader] You visited ' + pathname + '; redirecting to ' + defaultPath);
+        message = '[Loader] You visited ' +
+            pathname +
+            '; redirecting to ' +
+            defaultPath;
+        console.log(message);
         page(defaultPath);
     }
 
