@@ -11,14 +11,17 @@ var componentList = {
     tabBar: require('../components/tabBar'),
     templateCell: require('../components/templateCell'),
     slideToggle: require('../components/slide-toggle'),
-    alert: require('../components/alert')
+    alert: require('../components/alert'),
+    dataRepresentation: require('../components/dataRepresentation'),
+    switch: require('../components/switch'),
+    loadingIndicator: require('../components/loadingIndicator')
 };
 
 // Add all blocks
 var blocks = clone(bulk(__dirname + '/../blocks', '**/*.js'));
 
 for (var id in blocks) {
-    if(blocks.hasOwnProperty(id)) {
+    if (blocks.hasOwnProperty(id)) {
         componentList[id] = block.extend(blocks[id]);
     }
 }
