@@ -10,7 +10,22 @@ module.exports = view.extend({
     id: 'add',
     template: require('./index.html'),
     data: {
-        blocks: blocks
+        // Provide a specific sort order
+        blocks: [
+            blocks.text,
+            blocks.image,
+            blocks.sms,
+            blocks.phone,
+
+            // Include spacers for missing blocks
+            undefined,
+            undefined,
+
+            // Form / data blocks
+            blocks.input,
+            blocks.spinner,
+            blocks.submit
+        ]
     },
     created: function () {
         var self = this;
