@@ -5,7 +5,7 @@ module.exports = view.extend({
     id: 'edit',
     template: require('./index.html'),
     data: {
-        back: '/profile',
+        back: true,
         doneLabel: 'Publish'
     },
     created: function () {
@@ -18,7 +18,7 @@ module.exports = view.extend({
         // Bind app
         self.$data.app = app.data || {};
         self.$data.onDone = '/make/' + id + '/share?publish=true';
-        self.$data.removeApp = function() {
+        self.$data.removeApp = function () {
             app.removeApp();
             self.page('/profile');
         };
